@@ -364,12 +364,14 @@ class PCS:
         # Compute features based on optimize_params
         X = self.compute_features(llm_preds, selected_indices, optimize_params)
         print("X", X)
+        print(y)
         # Train linear regression model
         model = LinearRegression(positive=True)  # Ensure positive weights
         model.fit(X, y)
         
         # Extract weights from coefficients
         coefficients = model.coef_
+        print("coefficients", coefficients)
         weights = np.sum(coefficients, axis=0)
         print("weights", weights)
         # Initialize weights
